compute.average.ROC <-
function(
#ROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROC	
							curves, weight=1/length(curves),features.names=names(curves[[1]]),
							title="ROC",curve.colnames,
							above=0,below=NA,
							xlim=c(0,min(below,1,na.rm=TRUE)),ylim=c(above,1),
							path=NA,file.name="ROC",
							legend.title="Area under the ROC curve",
							legend.show="AUC",
							show.zoom.area=FALSE,
							show.diagonal =TRUE,
							skip=c(),
							colors=features.colors,
							digits.num =3,
							legsize=1.5,
							point.to.classic=TRUE,
							## cex.lab=1,
							...){
	### INPUT: curve[[3]] is a n*2 matrix of the ROC curve from some project section.
	#			curve is a list of length at leat 2.
	# plots the results as well.
	output.curves <- list()
	AUC <- c()	# area under the ROC curve, 
	Gini <- c()				
	legend.numbers <- list()
		# legend.numbers[["AUC"]] = above the X=above line and on the right of the below Y=line.

	# to save plot:
	if(!is.na(path))
		postscript(file=paste(path,"/",file.name,".eps",sep=""))	

	features.names <- features.names[!features.names %in% skip]
	# for all feature names:
	for(j in 1:length(features.names)){
		feature.name <- features.names[j]
		#print(feature.name);a()
		output.curves[[feature.name]] <- curves[[1]][[feature.name]]
		output.curves[[feature.name]][ ,2] <- weight[1] * output.curves[[feature.name]][ ,2]	
			# corresponding to the nnumber of cases in the first project section.
		for (i in 2:length(curves)){	# for all porject sections	
			#*********************************************************************************************************************************			
			output.curves[[feature.name]] <- sum.curves(output.curves[[feature.name]],curves[[i]][[feature.name]],
				weight1=1, weight2=weight[i])
			#*********************************************************************************************************************************			
		}#End for.
		output.curves[[feature.name]] <- rbind(c(1,1),output.curves[[feature.name]],c(0,0))	# the first and last points
		colnames(output.curves[[feature.name]]) <- curve.colnames
		# AUC	
		AUC[feature.name] <- compute.area.under.the.curve(curve.matrix=output.curves[[feature.name]],
										above.x=above,left.of.y=below,increasing.x=FALSE)	
		Gini[feature.name] <- 2*compute.area.under.the.curve( curve.matrix= output.curves[[feature.name]],
			increasing.x=FALSE) -1	
		#plot
		par(mar=1.15* (c(5, 4, 4, 2)) +0.01, cex.lab=2.3)
		plot(output.curves[[feature.name]],type='l',xlim=xlim,ylim=ylim,xlab=NA,ylab=NA, col=colors[feature.name], 
			yaxt="n",xaxt="n", ...)	
		par(new=TRUE)
	}#End for.	
	legend.numbers[["AUC"]] <- format(round(AUC,digits=digits.num),nsmall=digits.num)
	legend.numbers[["Gini"]] <- format(round(Gini,digits=digits.num),nsmall=digits.num)

	# to add labels and title.
	par(mar=1.15* (c(5, 4, 4, 2)) +0.01, cex.lab=2.3)
	plot(output.curves[[feature.name]],type='l',lty=2,xlim=xlim,ylim=ylim,main=title,col=colors[feature.name],
		yaxt="n",xaxt="n",...)
	axis(1,cex.axis=2.3); axis(2,cex.axis=2.3)	
	#	
	#aligned <- align.strings(features.names)
	par(font=2)	#For bold title
	legend.text <- paste("(",legend.numbers[[legend.show]],") - ",features.names,sep="")
	legend("bottomright", legend.text , cex=legsize, col=colors[features.names], title=legend.title,
		text.col="white",title.col="black")
		 #	Efficient: above the 50% threshold for Sensitivity and Specificity
	par(font=1)
	legend("bottomright", legend.text, cex=legsize, col=colors[features.names], pch=19,title="")
	if(point.to.classic){
			text(0.59,0.2,"{",cex=6)
			text(0.56,0.2,"common practice",srt=90)
	}#End if.		
	#		
	#random line x=y.
	if(show.diagonal)
		lines(c(0,1),c(0,1),col="grey",lty="dashed")	
	grid(col="grey")
	if(show.zoom.area){
		lines(c(-0.02,0.5),c(0.5,0.5),lty="twodash",col="lightgrey")
		lines(c(0.5,0.5),c(0.5,1.02),lty="twodash",col="lightgrey")	
		lines(c(0.5,-0.02),c(1.02,1.02),lty="twodash",col="lightgrey")	
		lines(c(-0.02,-0.02),c(1.02,0.5),lty="twodash",col="lightgrey")		
	}#End if.			
	if(!is.na(path))
		dev.off()
	#			
	return(list(curves=output.curves,efficient.AUC=legend.numbers[["AUC"]],Gini=legend.numbers[["Gini"]]))
}#End. ROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROCROC

