plot.ROC <-
function(values, labels,curve.colnames,colors=features.colors,...){
### Plots the Receiver operating characteristic curves ROCROCROCROCROCROCROC
### corresponding to the columns of the values matrix. 
###INPUT: 	labels should be a vector in range [0,1].
#			curve.colnames will be added as the axes labels.

	AUC <- c()
	values <- as.matrix(values)
	if(is.null(colnames(values)))
		colnames(values) <- 1:dim(values)[2] 
	#print("ROC");a()
	ROC.curve <- list()	# Each element is a 2*n matirx describing a (1-Sensitivity,Specificity) curve.
	for(i in 1:dim(values)[2] ){
		colname <- colnames(values)[i]	# The name of the ith feature.
		library(Epi)
		ROC.result <- Epi::ROC(values[ ,colname],labels,plot=c())
		if(ROC.result$AUC< 0.5)	# This feature 
			ROC.result <- Epi::ROC(-values[ ,colname],labels,plot=c())
		AUC[colname] <- ROC.result$AUC
		Sensitivity <- ROC.result$res[,"sens"]
		Specificity <- ROC.result$res[,"spec"]		
		pert <- (1-(i%%3)*0.01)	# to a move the plots a little for better visualization.
		SS <- cbind(1-Specificity,Sensitivity)
		colnames(SS) <- curve.colnames 
		SS.pert <- SS * pert
		par(mar=1.15* (c(5, 4, 4, 2)) +0.01, cex.lab=2.3)
		plot(SS.pert,col=colors[colname],type='l',ylab=NA,xlab=NA,xlim=c(0,1),ylim=c(0,1),...)
		par(new=TRUE)	
		ROC.curve[[colname]] <- SS
	}#end for.	
	title <- paste(dim(values)[1]," cases")
	par(mar=1.15* (c(5, 4, 4, 2)) +0.01, cex.lab=2.3)
	plot(SS.pert,col=colors[colname],type='l',xlim=c(0,1),ylim=c(0,1),main=title,...)	# To add the xy-labels.
	AUC <- round(AUC,2)
	Gini <- 2*AUC -1	#Gini index
	#
	par(font=2)	#For bold title
	legend("bottomright", paste(colnames(values),"(",AUC,")",sep=""), cex=1, col=colors[colnames(values)],
		title="Area under the ROC curve",text.col="white",title.col="black")
	par(font=1)
	legend("bottomright", paste(colnames(values),"(",AUC,")",sep=""), cex=1, col=colors[colnames(values)],pch=19,
		title="")
	grid()
	return(list(AUC=AUC,Gini=Gini,ROC.curve=ROC.curve))
}#End plot.ROC <- function.

