plot.ratio <-
function(ratio,numerator.marker="NM", denominator.marker="DM",cutoff=NA,maping,
						location_legend="topleft",
						title=NULL,input.colors=type.colors,standard.patients=0.5,path=NA,eps.format=FALSE,
						pch.for_standard=20,pch.for_non.standard=8,border.color="green",reverce=FALSE,
						clinical.tests=NULL,legcex=1.5,add.legend=TRUE,
						legend.text=ratios.legend.text,
						ylab=NA,
						cex=1.5,axes=TRUE,
						yaxt="s",
						...) {
### INPUTS
# maping:	accoring to the label of each case, determines its color (patCode.2.diagnosis).	

### standard.tube is the one that contains FMC& nand CD23.
### standard.patients=0.5, in case it is not mentioned.
	Ps <- pch.for_standard
	Pn <- pch.for_non.standard
	pch.symbols <- Pn+(Ps-Pn)*as.numeric(standard.patients[names(ratio)])
	patcodes <- names(ratio)
	names(pch.symbols) <- patcodes
	if(!is.null(clinical.tests)){	# We recompute pch symbols.	
		standard <- clinical.tests[patcodes, "standard"]
		fish <- clinical.tests[patcodes, "FISH.11.14"]
		cyclin.d1 <- clinical.tests[patcodes, "cyclin.D1.IHC"]
		ns <- 64; pch.symbols[patcodes] <- ns	# non-standard
		fneg <- 22; pch.symbols[fish=="FALSE"] <- fneg	# FISH negative
		fpos <- 17; pch.symbols[fish=="TRUE"] <- fpos	# FISH positive
		cneg <- 4; pch.symbols[cyclin.d1=="FALSE"] <- cneg #cyclin D1 negative
		bneg <- 7; pch.symbols[fish=="FALSE" & cyclin.d1=="FALSE"] <- bneg # both negative				
		stan <- 20; pch.symbols[standard=="TRUE"] <- stan	# standard
	}#End if.
	#
	#revercing if necessary:
	if(reverce){ 
		ratio <- rev(ratio)
		pch.symbols <- rev(pch.symbols)
	}#End if.	
	#
	# preparing for vertical line:
	type.nums <- patcode.2.type.num(names(ratio),maping=maping)
	first.num <- length(which(type.nums==type.nums[1]))

	if(is.null(title))
		title <- paste("relative intensity of ", refine.marker.name(numerator.marker),"to", 
			refine.marker.name(denominator.marker))

	#file name:
	ploting.file <- paste(path,replace.character(input.string=title,replacable=" ",with="_"),sep='/')

	if(!is.na(path)){
		if(!eps.format)
			bmp(file=paste(ploting.file,".bmp",sep=""))
		if(eps.format)	
			postscript(file=paste(ploting.file,".eps",sep=""))
	}#End if.	
	color.ploting <- input.colors[patcode.2.type(patcodes=names(ratio),maping=maping)]
	indices <- 10*(1:(length(ratio) %/% 10 -1))
	indices <- c(1,indices, length(ratio))
	#*************************************************************************************************************
	par(mar=1.15* (c(5, 4, 4, 2)) +0.01, cex.lab=2)
	plot(ratio, col= color.ploting, main=title, pch=pch.symbols,mar=1.15* (c(5, 4, 4, 2)) +0.01, cex.lab=2,cex=cex, ylab=ylab, axes=axes, xlab="case index", xaxt="n", yaxt=yaxt)
	axis(1, at=indices)
	#**************************************************************************************************************
	# legend llllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllll
	if(add.legend){
		if(is.null(clinical.tests)){
			legend(x=location_legend, c("MCL","SLL","non-standard"), cex=legcex,
			 col=c(input.colors["MCL"],input.colors["SLL"],"black"), pch=c(Ps,Ps,Pn))
		} else	
		legend(x=location_legend,legend.text, 
			cex=legcex, col=c(input.colors["MCL"],input.colors["SLL"],"black",
			input.colors["MCL"],input.colors["SLL"],input.colors["SLL"],input.colors["SLL"]),
			pch=c(stan,stan,ns,fpos,fneg,cneg,bneg))	
	}#End if(add.legend).		
	# End legend lllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllll		
	abline(v=first.num+0.5,col="grey")	
	if(!is.na(cutoff))
		abline(h=cutoff,col=border.color)
	if(!is.na(path))			
		dev.off()
	print("plot.ratio-ending")				
	return(list(first.class.num=first.num,pch.symbols))
}#End plot.ratio <- function.plot.ratioplot.ratioplot.ratioplot.ratioplot.ratioplot.ratioplot.ratioplot.ratioplot.ratioplot.ratioplot.ra

